@@ -195,16 +195,17 @@ getPrices <- function(instrument, granularity, count = NULL, from = NULL,
                             `Accept-Datetime-Format` = "UNIX",
                             `User-Agent` = .user_agent),
                 response = "date")
-  .subset2(resp, "status") == 200L ||
-    stop("status code ", .subset2(resp, "status"), " - ",
-         deserialize_json(.subset2(resp, "raw"), simplify_to = 3L), call. = FALSE)
-  timestamp <- as.POSIXct.POSIXlt(strptime(.subset2(.subset2(resp, "headers"), "date"),
+  resp[["status"]] == 200L ||
+    stop("status code ", resp[["status"]], " - ",
+         deserialize_json(resp[["raw"]]), call. = FALSE)
+  timestamp <- as.POSIXct.POSIXlt(strptime(resp[["headers"]][["date"]],
                                            format = "%a, %d %b %Y %H:%M:%S", tz = "UTC"))
-  candles <- deserialize_json(.subset2(resp, "raw"), query = "/candles", simplify_to = 3L)
+  candles <- deserialize_json(resp[["raw"]], query = "/candles")
   ptype <- switch(price, M = "mid", B = "bid", A = "ask")
+  browser
 
   !missing(.validate) && .validate == FALSE && {
-    data <- `storage.mode<-`(unlist(.subset2(candles[[1L]], ptype)), "double")
+    data <- `storage.mode<-`(unlist(candles[[1L]][[ptype]]), "double")
     return(c(t = unclass(timestamp), data))
   }
 
@@ -348,8 +349,8 @@ oanda_stream <- function(instrument, display = 8L, limit, server, apikey) {
 
   while (length(page <- readLines(con, n = 1L, encoding = "UTF-8"))) {
 
-    json <- deserialize_json(page, simplify_to = 3L)
-    .subset2(json, "type") == "PRICE" || next
+    json <- deserialize_json(page)
+    json[["type"]] == "PRICE" || next
     json[["type"]] <- NULL
     json[["time"]] <- .POSIXct(.subset2(json, "time"))
     cat("\f", file = stdout())
@@ -1011,15 +1012,15 @@ oanda_positions <- function(instrument, time, server, apikey) {
   resp <- ncurl(url, convert = FALSE, follow = TRUE,
                 headers = c(Authorization = paste0("Bearer ", apikey),
                             `Accept-Datetime-Format` = "UNIX", `User-Agent` = .user_agent))
-  .subset2(resp, "status") == 200L ||
-    stop("status code ", .subset2(resp, "status"), " - ",
-         deserialize_json(.subset2(resp, "raw"), simplify_to = 3L), call. = FALSE)
-  data <- deserialize_json(.subset2(resp, "raw"), query = "/positionBook", simplify_to = 3L)
-  currentprice <- as.numeric(.subset2(data, "price"))
-  timestamp <- .Call(ichimoku_psxct, .subset2(data, "unixTime"))
-  bucketwidth <- as.numeric(.subset2(data, "bucketWidth"))
+  resp[["status"]] == 200L ||
+    stop("status code ", resp[["status"]], " - ",
+         deserialize_json(resp[["raw"]]), call. = FALSE)
+  data <- deserialize_json(resp[["raw"]], query = "/positionBook")
+  currentprice <- as.numeric(data[["price"]])
+  timestamp <- .Call(ichimoku_psxct, data[["unixTime"]])
+  bucketwidth <- as.numeric(data[["bucketWidth"]])
 
-  buckets <- `storage.mode<-`(do.call(rbind, .subset2(data, "buckets")), "double")
+  buckets <- `storage.mode<-`(do.call(rbind, data[["buckets"]]), "double")
   df <- `attributes<-`(list(buckets[, "price"],
                             buckets[, "longCountPercent"],
                             buckets[, "shortCountPercent"]),
@@ -1103,15 +1104,15 @@ oanda_orders <- function(instrument, time, server, apikey) {
   resp <- ncurl(url, convert = FALSE, follow = TRUE,
                 headers = c(Authorization = paste0("Bearer ", apikey),
                             `Accept-Datetime-Format` = "UNIX", `User-Agent` = .user_agent))
-  .subset2(resp, "status") == 200L ||
-    stop("status code ", .subset2(resp, "status"), " - ",
-         deserialize_json(.subset2(resp, "raw"), simplify_to = 3L), call. = FALSE)
-  data <- deserialize_json(.subset2(resp, "raw"), query = "/orderBook", simplify_to = 3L)
-  currentprice <- as.numeric(.subset2(data, "price"))
-  timestamp <- .Call(ichimoku_psxct, .subset2(data, "unixTime"))
-  bucketwidth <- as.numeric(.subset2(data, "bucketWidth"))
+  resp[["status"]] == 200L ||
+    stop("status code ", resp[["status"]], " - ",
+         deserialize_json(resp[["raw"]]), call. = FALSE)
+  data <- deserialize_json(resp[["raw"]], query = "/orderBook")
+  currentprice <- as.numeric(data[["price"]])
+  timestamp <- .Call(ichimoku_psxct, data[["unixTime"]])
+  bucketwidth <- as.numeric(data[["bucketWidth"]])
 
-  buckets <- `storage.mode<-`(do.call(rbind, .subset2(data, "buckets")), "double")
+  buckets <- `storage.mode<-`(do.call(rbind, data[["buckets"]]), "double")
   xlen <- dim(buckets)[1L]
   df <- `attributes<-`(list(buckets[, "price"],
                             buckets[, "longCountPercent"],
@@ -1152,4 +1153,3 @@ oanda_orders <- function(instrument, time, server, apikey) {
   invisible(df)
 
 }
-
